==> cuyo_1.04.orig.tar.gz: cuyo-1.04/src/bilddatei.h <==
/***************************************************************************
                          bilddatei.h  -  description
                             -------------------
    begin                : Fri Apr 20 2001
    copyright            : (C) 2001 by Immi
    email                : cuyo@karimmi.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef BILDDATEI_H
#define BILDDATEI_H

#include "inkompatibel.h"

#include <qstring.h>
#include <qcolor.h>
#include <qpixmap.h>

#define gric 32 // Gre der Bildchen

/* Die vier Viertel eines Bildchens; Achtung: Wenn diese Konstanten
   gendert werden, muss auch einiges in Sorte gendert werden */

#define viertel_alle -1
#define viertel_lo 0
#define viertel_ro 1
#define viertel_lu 2
#define viertel_ru 3


/**verwaltet ein xpm als Ansammlung von 16x16-Bildchen
  *@author Immi
  */

class Bilddatei {
 public: 
  Bilddatei();
  ~Bilddatei();

  /** Ldt das Bild mit dem angegebenen Namen. Throwt ggf. */
  void laden(__String name);
  /** Ldt das Bild mit dem angegebenen Namen und ndert alles, was wei ist,
      in die angegebene Farbe. Throwt ggf. */
  void ladenSpezial(__String name, QColor weissersatz);
  /** ldt ein Bildchen und speichert es in bild; sucht in verschiedenen
      Pfaden danach. Throwt ggf. */
  void ladImage(QImage & bild, __String name);
	
	
  /** malt das n-te Bildchen an xx,yy */
  //void malBildchen(QPainter & p, int xx, int yy, int n) const;
  /** malt das k-te Viertel vom n-te Bildchen an xx,yy. Oder evtl. das
      ganze Bildchen */
  void malBildchen(QPainter & p, int xx, int yy,
		   int n, int k = viertel_alle) const;
  /** liefert zurck, wie viele Bildchen in dieser Datei sind. */
  int anzBildchen() const;
  /** malt das gesamte Bild */
  void malBild(QPainter & p, int xx, int yy) const;
  /** liefert die Gesamtbreite in Pixeln zurck */
  int getBreite() const;
  /** liefert die Gesamthoehe in Pixeln zurck */
  int getHoehe() const;

  /** liefert true, wenn das Bild (erfolgreich) geladen ist */
  bool istGeladen() const {return !mBild.isNull();}
	
 protected:
  QPixmap mBild;

	
  /** liefert die Pos des Bildchens Nr. n */
  QPoint bildchenPos(int n) const;

};

#endif

==> cuyo_1.8.5.orig.tar.gz: cuyo-1.8.5/src/bilddatei.h <==
/***************************************************************************
                          bilddatei.h  -  description
                             -------------------
    begin                : Fri Apr 20 2001
    copyright            : (C) 2001 by Immi
    email                : cuyo@karimmi.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef BILDDATEI_H
#define BILDDATEI_H

#include "inkompatibel.h"

#include <qstring.h>
#include <qcolor.h>
#include <qpixmap.h>

#define gric 32 // Gre der Bildchen

/* Zur bergabe an malBildchen(): Welches Viertel soll gemalt werden?
   Entweder viertel_alle bergeben oder
   viertel_q** | viertel_z**
   Ersteres (Quelle) gibt an, welches Viertel aus der Datei genommen wird,
   zweiteres (Ziel) in welches Viertel gemalt wird.
*/
#define viertel_alle -1

/* Achtung: Wenn die nachfolgenden Konstanten gendert werden, muss
   auch const_werte in blop.cpp gendert werden. */
#define viertel_qlo 0
#define viertel_qro 1
#define viertel_qlu 2
#define viertel_qru 3

#define viertel_zlo 0
#define viertel_zro 4
#define viertel_zlu 8
#define viertel_zru 12

/* Bit-Masken... */
#define viertel_qr 1
#define viertel_qu 2
#define viertel_zr 4
#define viertel_zu 8

/* Fr range-Check (siehe BildStapel::speichereBild()) */
#define viertel_min -1
#define viertel_max 15


/**verwaltet ein xpm als Ansammlung von 16x16-Bildchen
  *@author Immi
  */

class Bilddatei {
 public: 
  Bilddatei();
  ~Bilddatei();

  /** Ldt das Bild mit dem angegebenen Namen. Sucht in verschiedenen
      Pfaden danach.Throwt ggf. */
  void laden(__String name);
	
	
  /** malt das n-te Bildchen an xx,yy */
  //void malBildchen(QPainter & p, int xx, int yy, int n) const;
  /** malt das k-te Viertel vom n-te Bildchen an xx,yy. Oder evtl. das
      ganze Bildchen */
  void malBildchen(QPainter & p, int xx, int yy,
		   int n, int k = viertel_alle) const;
  /** liefert zurck, wie viele Bildchen in dieser Datei sind. */
  int anzBildchen() const;
  /** malt das gesamte Bild */
  void malBild(QPainter & p, int xx, int yy) const;
  /** Speziell fr die Debug-Output-Ziffern: Malt Ziffer n. */
  void malZiffer(QPainter & p, int xx, int yy, int n) const;
  /** liefert die Gesamtbreite in Pixeln zurck */
  int getBreite() const;
  /** liefert die Gesamthoehe in Pixeln zurck */
  int getHoehe() const;

  /** liefert true, wenn das Bild (erfolgreich) geladen ist */
  bool istGeladen() const {return !mBild.isNull();}
	
 protected:
  QPixmap mBild;

	
  /** liefert die Pos des Bildchens Nr. n */
  QPoint bildchenPos(int n) const;

};

#endif
